{% extends "base.html" %}
{% from 'bootstrap4/form.html' import render_form, render_field %}

{% block app_content %}

<div class="container">
   <div class="row">
       <div class="col-6">

            <br>
            <h4> Model Data Browser</h4>
            <nav aria-label="...">
               <ul class="pager">
               <li class="model">
                  <a href="{{ url_for('main.models') }}"> List Models </a>
               </li>
               <li class="nodes">
                  <a href="{{ url_for('main.entities',entities='nodes') }}"> List Nodes </a>
               </li>
               <li class="properties">
                  <a href="{{ url_for('main.entities',entities='properties') }}"> List Properties </a>
               </li>
               <li class="terms">
                  <a href="{{ url_for('main.entities',entities='terms') }}"> List Terms </a>
               </li>
               <li class="origins">
                  <a href="{{ url_for('main.entities',entities='origins') }}"> List Origins </a>
               </li>
            </ul>
            </nav> 
         <br>
      </div>

<div class="col-6">
      <br>
      <h4> About </h4>
      <ul class="pager">
        <li class="aboutmdb">
         <a href="{{ url_for( 'main.about_mdb') }}">About MDB</a>
        </li>
        <li>
         <a href="{{ url_for( 'main.about_sts') }}">About STS</a> and how to filter
        </li>
       </ul> 

   <br>
   <h4> Reports and Version History</h4>
   <ul class="pager">
      </ul>     

   <br>
   <h4> External Resources</h4>
   <ul class="pager">

      <li class="ncit">
         <a href="https://ncithesaurus.nci.nih.gov/ncitbrowser/"> NCI Thesaurus</a>
      </li>
        <li class="evs">
              <a href="https://evs.nci.nih.gov/"> NCI EVS</a>
        </li>
        <li class="cde">
         <a href="https://cdebrowser.nci.nih.gov/cdebrowserClient/cdeBrowser.html#/search"> NCI CDE Browser </a>
      </li>
      <li class="umls">
         <a href="https://www.nlm.nih.gov/research/umls/index.html"> UMLS</a>
      </li>
      </ul>
   </div>

</div>
</div>
{% endblock %}
